# Chapter 3: Methods

A meta analysis was conducted to measure the effectiveness of Internet- and Cell phone- based interventions for the quitting and prevention of longer term relapse of smoking. The rationale and steps of the meta analysis are presented below.

## The Role of this Meta-Analysis
 
The purpose of this meta analysis was to investigate the role of Internet-and Cell phone-based interventions ‘delivered via email, accessing websites, text messages’ to achieve longer-term cessation of smoking among adult smokers. In meta analysis, results from two or more primary studies are pooled to arrive at a summary estimate. Meta analyses refer to a systematic process of framing a research question, conducting a search of the available literature, assessment of the similarities or homogeneity of the studies, and after establishment of whether the studies are homogeneous or heterogeneous, the results from these studies are pooled together in a number of different ways to arrive at a set of summary results.  

Meta analyses are useful for the following reasons: (1) using meta analyses, it is useful to achieve an increase in power by pooling together small studies; (2) improve accuracy known as the estimation of intervention effect which can be improved if it is based on more information, to assist in answering questions which are not presented by individual primary studies due to them involving a specific type of participants and specifically defined interventions, this way a selection of studies in which these specific characteristics differ can allow investigation  of the consistency of effect and reasons for the difference in effect estimates, to settle controversies arising from apparently conflicting studies and to generate new hypotheses. For this reason this statistical analysis of findings allows the degree of conflict to be formally assessed and reasons for different results to be explored and quantified.

## Steps of the Meta Analysis

Now write the steps of the meta analysis in clear simple English so that anyone reading this can reproduce your steps. Write under the following headings:

## Study Question

Compared with traditional or all other approaches that do not use the Internet or Cell phone-based messaging as their primary means, what is the effectiveness of Internet based and Cell phone-based interventions for longer term smoking cessation among smokers and for longer term quitting?

## Inclusion and Exclusion criteria for Studies
Studies were included in this research if they met the following criteria:

1.The research studied adolescents and adult population aged between 15 and 64 years residing anywhere in the world
2.The research assessed Internet and Cell phone-based interventions inclusive of but not limited to access to websites containing information about the dangers of smoking, quitting, relapse prevention, questionnaires,discussion forums, access to private chat messages, quitting diary, informative and motivational emails and text messages including advice and suggestions about strategies on how to cope with craving situations and interactive voice response. Studies were included if they offered Nicotine Replacement Therapy or Telephone Calls in addition to the Internet and Cell phone.
3.The research compared Internet-and Cell phone-based interventions with a)interventions which did not include any Internet-or Cell phone components and included but were not limited of self-treatment, phone or face to face counseling, herbal remedies, e-cigarette, hypnosis and those which included b)Internet or Cell phone components but at a lower frequency
4.The research assessed studies whose primary outcome was abstinence of smoking for at least 6 months after the start of the intervention or 12 months wherever data was available.
5.The research measured self-reported abstinence and included the ones that included biochemical validation.
6.The research was an Randomized Controlled Trail(RCT) because they use high quality.
7.The research was conducted in English Language or a written translation was available.
8.The research was published between the 1st January 2004 to 1st April 2014.
 
**Finish the list**. 

A study was excluded from this research if:

* The study did not have adults as the participants
* If the study was not reported in English language or a translated version was not available
* ...

**Finish this list**

## Search Terms and Databases Searched

**We want a detailed breakdown of the search strategy**

The following search terms for the database search included: “smok” OR “smoking” OR “tobacco” OR “cigarette” OR “nicotine” OR “tobacco smoking” OR “cigarette smoking” AND “smoking cessation” OR “nicotine withdrawal” OR “tobacco cessation” OR “online therapy” OR “quit” OR “quitting” OR “e-therapy” OR “electronic therapy” AND “Internet” OR “online” OR “net” OR “world-wide web” OR “web” OR “www” OR “computer-mediated communication” OR “facebook” OR “twitter” OR “blog” OR “cellular phone” OR “cellphone” OR “mobile phone” OR “text-messaging” OR “text” OR “txt” OR “sms” OR “mms” AND “young adult (19-24 years)” OR “adult (19-44 years)” OR “young adult & adult (19-24 years & 45-64 years)” OR “middle age (45 plus years) AND “English Language” AND “2004-2014”.

The following databases of the literature were searched:
A search through Pubmed, Medline, Google Scholar, Psyc Literature, CINAHL (Cumulative Index of Nursing & Allied Health Literature Database, Web of Science, Collected Health Literature Related Databases which are maintained at UC and the Cochrane Database of Systematic Reviews or CDSR was conducted. 



Write here in details what search terms were employed and what databases were searched. How did you know that the search terms you used were good enough?

List all the databases you searched in the following list. 

## Appraisal of the Studies Based on their Titles and Abstracts

This is the first pass of the meta analysis. Write here what did you do to filter studies based on their titles and abstracts. If the title and or the abstract did not match your expectations or did not meet the inclusion criteria for this study then they were removed from further consideration. Write those here. 

## Search for fugitive literature and grey literature

Fugitive literature refers to those studies where the author may have conducted a study but  he did not publish it anywhere. Alternatively, the author may have sent for publication but that did not get published. It is possible to find out about gray literature from trials databases, and occasionally asking experts, etc. Describe what did you do about finding out grey literature in this research.

## Hand searches from the lists of references from the literature reviewed

You need to convince your readers that you did as comprehensive a search as possible. Write here that you rand hand searches following reading the full texts of all studies included in the full text appraisal to look for more studies. So, you searched the University of Canterbury library archives, etc. Write that in details here. 

## Critical Appraisal of the studies included in the full text
Assessment of Risk of Bias in included studies
Bias was assessed using the Cochrane Collaboration’s tool for assessment of Risk of Bias (Higgins 2011a, Higgins 2011b). The following criteria was assessed using the “Cochrane Collaboration Risk of Bias Tool” which is a domain- based evaluation and includes the following parts: Random sequence generation (selection bias), Allocation concealment (selection bias), Blinding (performance bias and detection bias, blinding of participants), incomplete outcome data (attrition bias), selective reporting (reporting bias) and other bias (publication bias). The Risk of Bias criteria was judged as “low risk”, “high risk” or “unclear risk” (lack of information or uncertainty over the potential bias). The following table is the guide with the specific questions of the “Risk of Bias Tool

Table. “Cochrane Collaboration Risk of Bias Tool”
Bias	Question
Random Sequence generation	Was the allocation sequence adequately generated?
Allocation Concealment	Was the allocation adequately concealed?
Blinding	Was knowledge of the allocated interventions adequately prevented during the study?
Incomplete  Outcome Data	Were incomplete outcome data adequately addressed?
Selective Outcome Reporting	Are reports of the study free of suggestion of selective outcome reporting?
Other Sources of  Bias	Was the study apparently free of other problems that could put it at a high risk of bias?



Write here how were the full texts of the studies retrieved and what did you do to appraise them critically. There are critical appraisal checklists available. Write how you noted their biases and how you conducted their risk of bias tables. This table will be needed in the results section

## Summarising the Results of the Study: Random effects versus fixed effects meta analysis

First of all, discuss here what is meant by fixed effects versus random effects meta analysis. Then write, what did you do for this particular thesis. Give the equations and steps. State that you used R and Stata for this purpose. Summarising the results of the studies is done by creating Forestlots

A Meta-Analysis uses two models, one is the Fixed-Effects Method and the other one is the Random-Effects Method.

Fixed-Effects Method:
In a Fixed-Effects Analysis is assumed that all the included studies share a common true effect size µ. The observed effects are distributed about µ with a variance σ2 that depends primarily on the sample size of each study. There is only one level of sampling since all studies are sampled from a population with effect size µ and therefore only one source of sampling error exists within the studies. Since the goal of this approach is to assign more weight to the studies that carry more information, researchers may propose to weight each study by its sample size. So that for instance a study with one thousand subjects would get 10 times the weight of a study with one hundred subjects. Assignments of the weights are based on the inverse of the variance rather than the sample size. The inverse variance is roughly proportional to the sample size but is a more nuanced measure and serves to minimize the variance of combined effect.

Random-Effects Method:
The Fixed-Effects Method discussed above starts with the assumption that the true effect is the same in all included studies however the assumption may be implausible in some reviews. When a decision is made to incorporate a group of studies in a Meta-Analysis it is assumed that the studies have enough in common that it makes sense to synthesize the information rather than assume that there is one true effect. Rather than the assumption that there is one true effect, a distribution of true effect sizes is tolerated. The combined effect therefore cannot represent the common effect but instead represents the effect sizes and the mean of the population true effects. The Random- Effects Method consists of two level sampling and two sources of error. Firstly the true effect sizes 0 are distributed about µ with variance r² which reflects the actual distribution of the true effects about their mean; second the observed effect T for any given 0 is distributed about 0 with variance σ2 that depends primarily on the sample size for each study. When assigning weights to estimate µ there are two sources of sampling error, one within the studies and one between the studies to deal with. In the Fixed-Effects Analysis as comparison each study is weight by the inverse of its variance.  In the Random-Effects Analysis too, each study is weight by the inverse of its variance. However the difference is that the variance now includes the original (within-studies) variance plus the between-studies variance.






## Assessment of the heterogeneity of studies

An assessment of heterogeneity using I-squared statistics was conducted. I- squared statistics describes the percentage of variation across the different studies and it expresses the inconsistency of the results of the studies.This formula was used to calculate I-square "I" ^2=(("Q" -"df" ))/"Q"  "*" 100
If the studies were found to be statistically homogeneous based on the I-statistic cut off value (p= 0.1) then the results from these studies were combined. 
If on the other hand, the studies demonstrated a lack of homogeneity on the basis of statistical tests then the studies were further investigated to identify the causes of their heterogeneity.
 A significance level of 0.1 was used as an indication and the following interpretation guide was used: 0-40% indicates might not be important; 30-60% indicates “may represent moderate heterogeneity”; 50-70% “may represent substantial heterogeneity” and 75% or more indicates a “considerable level of inconsistency” (Higgins 2011a).


## Summarising the Studies: Odds Ratio and Forest PLot
 The results of the studies were combined and the following formula was used to calculate the Odds Ratio: 
 
 
 The findings are presented in a Forest Plot created using the Review Manager Software (RevMan). The Forest Plot illustrates the effect size and precision for each study (95% CI) and for the combined effect. It shows whether the combined effect is based on a few studies or many and whether the effect size is consistent or if it varies (OR 95% CI). Data entry is presented in two columns. The left- hand column includes the list the names of the studies (Randomized Controlled Trials). The right-hand column presents the plot of the measure of the effect (OR) for each of the studies which is illustrated as a square. The overall meta-analyzed measure of the effect is presented on the plot as a dashed vertical line. The meta-analyzed measure of effect is plotted as a diamond. Other points are used to indicate the confidence interval (CI) for the estimate. Then a vertical line which represents no effect was plotted. If the confidence intervals of the individual studies overlapped with the line it demonstrates that at given level of confidence their effect sizes do not differ from no effect for each individual study. If the points of the diamond overlapped the line of the no effect the overall meta-analyzed result meant it did not differ from no effect at the given level of confidence.

 
Give the formula for the Odds Ratio, the 95% Confidence Interval and write how you constructed the Forest Plot

## Testing for Publication Bias: visual inspection
Publication Bias was tested by setting up a Funnel Plot. The Funnel Plot is graphically presented and was created using the Review Manager Software (RevMan).This shows the assumptions that the largest studies are near the average and the small studies are spread on both sides of the average. If there are any variations shown from this assumption there is a likelihood that publication bias exists. A symmetric inverted funnel shape indicates well-presented data in which publication bias is very unlikely. And an asymmetric funnel shape indicates the relationship between the treatment effect and the study size.


## Subgroup Analysis

Write here that you conducted subgroup analyses following analysis of the entire data set. What were the criteria on the basis of which you selected the sub groups? Write that here. 


  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  